PCB Environment: StateRepresentation Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions | Protected Attributes
StateRepresentation Class Reference

The subclass create(PyObject *) functions check if the PyObject matches and return a new instace if it does, or 0 otherwise (or throw an exception if the name matches but the parameters don't). More...

`#include <StateRepresentation.hpp>`

## Public Member Functions
virtual PyObject * | getPy (PyObject *args)
virtual void | init (PCBoard &PCB)
virtual void | reset ()
virtual const char * | name () const
void | setFocus (const Connection *)
virtual void | setFocus (const std::vector< Connection * > *)
virtual void | updateView (const Bbox_2 *=0)
void | setLockedView (bool v)
virtual void | logAction (const Action *)
| logAction() is used for state representations like an action sequence as used e.g. by simple combinatorial optimization, or for efficiency.

## Static Public Member Functions
static StateRepresentation * | create (PyObject *)
| Create a new intance of a subclas as specified by the PyObject.

## Protected Attributes
PCBoard * | mPCB {0}
const Connection * | mFocus {0}
bool | mLockedView {false}

## Detailed Description

The subclass create(PyObject *) functions check if the PyObject matches and return a new instace if it does, or 0 otherwise (or throw an exception if the name matches but the parameters don't).

The StateRepresentation object abstracts the state representation and returns it in a PyObject. As such, using it makes sense only for use with Python policies.

## Member Function Documentation

## ◆ setFocus()

void StateRepresentation::setFocus | ( | const Connection * | X | ) |
| inline

Use setFocus() if you want to create an asymmetry in the state by highlighting a specific connection. This can also be an argument to getPy().

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/RL/StateRepresentation.hpp